<?php

namespace Drupal\Tests\disable_language\Functional;

use Drupal\language\Entity\ConfigurableLanguage;
use Drupal\Tests\BrowserTestBase;

/**
 * @coversDefaultClass \Drupal\disable_language\EventSubscriber\DisabledLanguagesEventSubscriber
 * @group disable_language
 */
class DisableLanguageRedirectTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['system', 'language', 'node', 'disable_language'];

  /**
   * The default theme.
   *
   * @var string
   */
  protected $defaultTheme = 'stable';

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    ConfigurableLanguage::load('en')
      ->setWeight(0)
      ->save();
    ConfigurableLanguage::createFromLangcode('nl')
      ->setWeight(1)
      ->save();
    ConfigurableLanguage::createFromLangcode('fr')
      ->setWeight(2)
      ->setThirdPartySetting('disable_language', 'disable', 1)
      ->setThirdPartySetting('disable_language', 'redirect_language', 'nl')
      ->save();

    if ($this->profile !== 'standard') {
      $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
    }
  }

  /**
   * Test redirects.
   */
  public function testRedirects() {
    $node = $this->drupalCreateNode(['title' => $this->randomString()]);
    $node->addTranslation('nl', ['title' => $this->randomString()]);
    $node->addTranslation('fr', ['title' => $this->randomString()]);
    $node->save();

    $allowed_user = $this->createUser(['view disabled languages']);
    $this->drupalLogin($allowed_user);
    $this->drupalGet('fr/node/' . $node->id());
    $this->assertSession()->addressEquals('fr/node/' . $node->id());
    $this->drupalLogout();

    $this->drupalGet('fr/node/' . $node->id());
    $this->assertSession()->addressEquals('nl');

    \Drupal::configFactory()
      ->getEditable('disable_language.settings')
      ->set('redirect_override_routes', ['entity.node.canonical'])
      ->save();
    drupal_flush_all_caches();
    $this->drupalGet('fr/node/' . $node->id());
    $this->assertSession()->addressEquals('nl/node/' . $node->id());

    \Drupal::configFactory()
      ->getEditable('disable_language.settings')
      ->set('redirect_override_routes', [''])
      ->set('exclude_request_path', ['pages' => '/node/*'])
      ->save();
    drupal_flush_all_caches();
    $this->drupalGet('fr/node/' . $node->id());
    $this->assertSession()->addressEquals('fr/node/' . $node->id());
  }

}
